<?php
/*
	Plugin Name: Browser Rejector
	Plugin URI: http://celloexpressions.com/dev/browser-rejector
	Description: Notify site visitors that they are using an outdated web browser, so the website may not display properly, displaying alternatives. Optionally completely block access.
	Version: 1.00
	Author: Nick Halsey
	Author URI: http://celloexpressions.com
	License: GPL2
*/

/*  Copyright 2012  Nick Halsey (email : halseyns@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

  
// Set-up Action and Filter Hooks
if ( is_admin() ){
	register_activation_hook(__FILE__, 'brejectr_add_defaults');
	register_uninstall_hook(__FILE__, 'brejectr_delete_plugin_options');
	add_action('admin_init', 'brejectr_init' );
	add_action('admin_menu', 'brejectr_add_options_page');
	add_filter( 'plugin_action_links', 'brejectr_plugin_action_links', 10, 2 );
} 

// Delete options table entries ONLY when plugin deactivated AND deleted
function brejectr_delete_plugin_options() {
	delete_option('brejectr_options');
}

// Define default option settings
function brejectr_add_defaults() {
	$tmp = get_option('brejectr_options');
    if(($tmp['chk_default_options_db']=='1')||(!is_array($tmp))) {
		delete_option('brejectr_options'); 
		$arr = array(	//rejection window
						"closeoption" => "yes",
						"bversions" => "latest",
						"headertext" => "Did you know that your internet browser is out of date?",
						"p1text" => "Your browser is out of date and may not be able to properly display our website. ",
						"p2text" => "A list of modern browsers is below; simply click an icon to go to the browser's download page.",	
							
						"closemessage" => "By closing this window you acknowledge that your experience on our website may be degraded.",
						"closelink" => "Close Window",
						"closecookie" => "no",
						
						//browsers to reject
						"msie5" => "1",
						"msie6" => "1",
						"msie7" => "1",
						"msie8" => "1",
						"msie" => "",
						
						"safari2-3" => "1",
						"safari4" => "",
						"safari" => "",
						
						"firefox1-2" => "1",
						"firefox3" => "1",
						"firefox" => "",
						
						"opera7-9" => "1",
						"opera10" => "1",
						"opera" => "",
						
						"chrome1-3" => "1",
						"chrome" => "",
						
						"chk_default_options_db" => ""
		);
		update_option('brejectr_options', $arr);
	}
}

// Init plugin options to white list our options
function brejectr_init(){
	register_setting( 'brejectr_plugin_options', 'brejectr_options', 'brejectr_validate_options' );
}

// Add menu page
function brejectr_add_options_page() {
	add_options_page('Browser Rejector Settings', 'Browser Rejector', 'manage_options', __FILE__, 'brejectr_render_form');
}

// Render the Plugin options form
function brejectr_render_form() {
	wp_enqueue_script('brejectr-admin-script', plugins_url('/brejectr-admin.js', __FILE__), array('jquery'));
	wp_enqueue_style('jreject-css', plugins_url('/jquery.reject.css', __FILE__));
	?>
	<!-- scripts and styles for the admin options page -->
	<style type="text/css">
		#brejectrsubpages { list-style-type: none; height: 32px; border-bottom: 1px solid #ababab; }
		.brejectrnav { float: left; border: 1px solid #ababab;  margin: 0 5px; }
		.brejectrnav h1 { font-size: 20px; padding: 2px 5px; line-height: 0; font-face: Arial, sans-serif; }
		.brejectrnav:hover, .brejectrnav:active { color: #21759b; cursor: pointer; }
		.brejectrcurrent { border-bottom: 1px solid #fff; color: #21759b; border-right: 1px solid #ababab; }
		.brejectrac {width: 500px; padding: 10px; font-size: 20px; font-weight: bold; font-family: Arial, sans-serif; background-color: #ababab; color: #21759b; border: 1px solid #ababab; }
		.brejectrac:hover {cursor: pointer; color: #11556b; border: 1px solid #eeeeee; }
		.brejectr_testimg {opacity: .7; filter:alpha(opacity=70); border-radius: 8px; width: 50px; } .brejectr_testimg:hover {opacity: 1; filter:alpha(opacity=100);}
		::selection { background-color: #000; color: #77f; text-shadow: none; }/*get rid of the ugly default blue, just for fun, and wordpress' text shadow (really???)*/
		a:hover { cursor: pointer; }
	</style>
	<div class="wrap">	
		<!-- Display Plugin Header, then the subpage navigation tabs -->
		<h2>Browser Rejector Settings</h2><?php // wp messages hook into the page content's first <h2>, so I can't use h1 here, so I do a modified h1 for the nav... ?>
		<ul id="brejectrsubpages">
			<li id="brejectrsuboptionspage_win" class="brejectrnav"><h1>Rejection Window</h1></li>
			<li id="brejectrsuboptionspage_tor" class="brejectrnav"><h1>Browsers to Reject</h1></li>
			<li id="brejectrsuboptionspage_preview" class="brejectrnav"><h1>Preview</h1></li>
		</ul>
		
		<!-- Beginning of the Plugin Options Form -->
		<form method="post" action="options.php">
			<?php settings_fields('brejectr_plugin_options'); ?>
			<?php $options = get_option('brejectr_options'); ?>

			<!-- Table Structure Containing Form Controls -->
			<!-- Each Plugin Option Defined on a New Table Row -->
			
			<!-- the general options page -->
			<table class="form-table" id="brejectr_tor">
				<!-- IE -->
				<tr valign="top">
					<th scope="row">Internet Explorer<br /><i>(Current Version: 9)</i></th>
					<td>
						<label><input name="brejectr_options[msie5]" type="checkbox" value="1" <?php if (isset($options['msie5'])) { checked('1', $options['msie5']); } ?> /> 5 (pre-xhtml standards)</label><br />
						<label><input name="brejectr_options[msie6]" type="checkbox" value="1" <?php if (isset($options['msie6'])) { checked('1', $options['msie6']); } ?> /> 6 (highly unpredictable)</label><br />
						<label><input name="brejectr_options[msie7]" type="checkbox" value="1" <?php if (isset($options['msie7'])) { checked('1', $options['msie7']); } ?> /> 7 (relatively unpredictable)</label><br />
						<label><input name="brejectr_options[msie8]" type="checkbox" value="1" <?php if (isset($options['msie8'])) { checked('1', $options['msie8']); } ?> /> 8 (no html5/css3 implementation)</label><br />
						<label><input name="brejectr_options[msie]" type="checkbox" value="1" <?php if (isset($options['msie'])) { checked('1', $options['msie']); } ?> /> All versions (discouraged except for testing purposes)</label>
					</td>	
				</tr>
				<!-- Safari -->
				<tr valign="top">
					<th scope="row">Safari<br /><i>(Current Version: 6)</i></th>
					<td>
						<label><input name="brejectr_options[safari2-3]" type="checkbox" value="1" <?php if (isset($options['safari2-3'])) { checked('1', $options['safari2-3']); } ?> /> 2-3 (no html5/css3)</label><br />
						<label><input name="brejectr_options[safari4]" type="checkbox" value="1" <?php if (isset($options['safari4'])) { checked('1', $options['safari4']); } ?> /> 4 (some html5/css3) - <i>Note: Android 3.x default browser identifies as Safari 4</i></label><br />
						<label><input name="brejectr_options[safari]" type="checkbox" value="1" <?php if (isset($options['safari'])) { checked('1', $options['safari']); } ?> /> All versions (discouraged except for testing purposes)</label>
					</td>	
				</tr>
				<!-- Firefox -->
				<tr valign="top">
					<th scope="row">Firefox<br /><i>(Current Version: 14)</i></th>
					<td>
						<label><input name="brejectr_options[firefox1-2]" type="checkbox" value="1" <?php if (isset($options['firefox1-2'])) { checked('1', $options['firefox1-2']); } ?> /> 1-2 (no html5/css3)</label><br />
						<label><input name="brejectr_options[firefox3]" type="checkbox" value="1" <?php if (isset($options['firefox3'])) { checked('1', $options['firefox3']); } ?> /> 3 (limited html5/css3, depending on 3.x version)</label><br />
						<label><input name="brejectr_options[firefox]" type="checkbox" value="1" <?php if (isset($options['firefox'])) { checked('1', $options['firefox']); } ?> /> All versions (discouraged except for testing purposes)</label>
					</td>	
				</tr>	
				<!-- Opera -->
				<tr valign="top">
					<th scope="row">Opera<br /><i>(Current Version: 12)</i></th>
					<td>
						<label><input name="brejectr_options[opera7-9]" type="checkbox" value="1" <?php if (isset($options['opera7-9'])) { checked('1', $options['opera7-9']); } ?> /> 7-9 (no html5/css3)</label><br />
						<label><input name="brejectr_options[opera10]" type="checkbox" value="1" <?php if (isset($options['opera10'])) { checked('1', $options['opera10']); } ?> /> 10 (early html5/css3 addoptions)</label><br />
						<label><input name="brejectr_options[opera]" type="checkbox" value="1" <?php if (isset($options['opera'])) { checked('1', $options['opera']); } ?> /> All versions (discouraged except for testing purposes)</label>
					</td>	
				</tr>	
				<!-- Chrome -->
				<tr valign="top">
					<th scope="row">Chrome<br /><i>(Current Version: 21)</i></th>
					<td>
						<label><input name="brejectr_options[chrome1-3]" type="checkbox" value="1" <?php if (isset($options['chrome1-3'])) { checked('1', $options['chrome1-3']); } ?> /> 1-3 (early html5/css3 addoptions)</label><br />
						<label><input name="brejectr_options[chrome]" type="checkbox" value="1" <?php if (isset($options['chrome'])) { checked('1', $options['chrome']); } ?> /> All versions (discouraged except for testing purposes)</label>
					</td>	
				</tr>
			</table>
				
			<!-- The Rejection Window Options -->
			<table class="form-table" id="brejectr_win">
				<!-- allow visitors to access site	-->
				<tr valign="top" >
					<th scope="row">Allow Visitors to Close the Rejection Window?<br /><i>Note: the window overlays your site with a semi-transparent background.</i></th>
					<td>
						<label><input name="brejectr_options[closeoption]" id="closeyes" type="radio" value="yes" <?php checked('yes', $options['closeoption']); ?> /> Yes <span style="color:#666666;margin-left:9px;">(visitors in rejected browsers can close the rejection message and continue to your site)</span></label><br />
						<label><input name="brejectr_options[closeoption]" id="closeno" type="radio" value="no" <?php checked('no', $options['closeoption']); ?> /> No <span style="color:#666666;margin-left:9px;">(visitors must install a modern broswer or Chrome Frame before accessing your site)</span></label><br />
					</td>
				</tr>
				<tr><td colspan="2"><b>Make sure that your theme's header.php file has this code so that your site will render IE in Chrome Frame when it's installed: </b><<code>meta http-equiv="X-UA-Compatible" content="chrome=1" /></code></td></tr>
				<!-- latest version or x+?	-->
				<tr valign="top">
					<th scope="row">Browser Suggestion Display</th>
					<td>
						<label><input name="brejectr_options[bversions]" type="radio" value="latest" <?php checked('latest', $options['bversions']); ?> /> Display latest browser version number <span style="color:#666666;margin-left:9px;">(plugin will be updated with each new browser version release, use if you keep your plugins up to date)</span></label><br />
						<label><input name="brejectr_options[bversions]" type="radio" value="plus" <?php checked('plus', $options['bversions']); ?> /> Display solid html5 version number+ <span style="color:#666666;margin-left:9px;">(use if you don't update your plugins frequently)</span></label><br />
					</td>
				</tr>
				<!-- text areas for the rejection window -->
				<tr valign="top">
					<th scope="row">Header Text<br /><i>NO DOUBLE QUOTES!!! (")</i></th>
					<td>
						<input type="text" size="100" name="brejectr_options[headertext]" value="<?php echo $options['headertext']; ?>" /><br />
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">Paragraph 1</th>
					<td>
						<input type="text" size="100" name="brejectr_options[p1text]" value="<?php echo $options['p1text']; ?>" /><br />
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">Paragraph 2</th>
					<td>
						<input type="text" size="100" name="brejectr_options[p2text]" value="<?php echo $options['p2text']; ?>" /><br />
					</td>
				</tr>
				
				<tr valign="top" id="closemessage" <?php if(brejectr_options_getOption('closeoption') == "no") { echo 'style="display:none"'; } ?>>
					<th scope="row">Close Message</th>
					<td>
						<input type="text" size="80" name="brejectr_options[closemessage]" value="<?php echo $options['closemessage']; ?>" /><br />
					</td>
				</tr>
				<tr valign="top" id="closelink" <?php if(brejectr_options_getOption('closeoption') == "no") { echo 'style="display:none"'; } ?>>
					<th scope="row">Close Link Text</th>
					<td>
						<input type="text" size="80" name="brejectr_options[closelink]" value="<?php echo $options['closelink']; ?>" /><br />
					</td>
				</tr>
				
				<!-- close cookies -->
				<tr valign="top" id="closecookies" <?php if(brejectr_options_getOption('closeoption') == "no") { echo 'style="display:none"'; } ?>>
					<th scope="row">Remember if the visitor closed the rejection message?</th>
					<td>
						<label><input name="brejectr_options[closecookie]" type="radio" value="yes" <?php checked('yes', $options['closecookie']); ?> /> Yes <span style="color:#666666;margin-left:9px;">(the rejection window will only be displayed once per session)</span></label><br />
						<label><input name="brejectr_options[closecookie]" type="radio" value="no" <?php checked('no', $options['closecookie']); ?> /> No <span style="color:#666666;margin-left:9px;">(the rejection window will be displayed every time a new page is visited)</span></label>
					</td>
				</tr>
				<!-- advanced/hidden options -->
				<tr valign="top" style="border-top:#dddddd 1px solid; display:none;" id="advanced">
					<th scope="row">Advanced Database Options (primarily for debugging)</th>
					<td>
						<label><input name="brejectr_options[chk_default_options_db]" type="checkbox" value="1" <?php if (isset($options['chk_default_options_db'])) { checked('1', $options['chk_default_options_db']); } ?> /> Restore defaults upon plugin deactivation/reactivation</label>
						<br /><span style="color:#666666;margin-left:2px;">Only check this if you want to reset plugin settings upon plugin reactivation</span>
					</td>
				</tr>
			</table>
			
			<table class="form-table" id="brejectr_preview">
				<?php 
					if(brejectr_options_getOption('bversions') == 'latest') {
						$ieversion = '9';
						$chromeversion = '21';
						$ffversion = '14';
						$operaversion = '12';
						$safariversion = '6';
					}
					else {
						$ieversion = '9+';
						$chromeversion = '4+';//auto updates from here
						$ffversion = '4+';//auto updates from here
						$operaversion = '11+';
						$safariversion = '5+';
					}
				?>
				<tr><td><p>Updates after saving options, not all browser options will be displayed at once - the suggested browsers vary based on OS (no Safari on Windows, no IE on Mac, Chrome Frame on IE only).</p></td></tr>
				<tr><td><p>Classes are also added to the html element in every browser, wich allow targeting of css for specific browsers. The classes are os, browser, browser version, rendering engine, rendering engine version (ex. win chrome chrome21 webkit webkit5).</p></td></tr>
				<tr><td>
					<div id="jr_inner" style="min-width: 400px; width: auto; ">
						<h1 id="jr_header"><?php echo brejectr_options_getOption('headertext'); ?></h1>
						<p><?php echo brejectr_options_getOption('p1text'); ?></p>
						<p><?php echo brejectr_options_getOption('p2text'); ?></p>
						<ul>
							<li id="jr_chrome" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_chrome.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.google.com/chrome/">Chrome <?php echo $chromeversion; ?></a></div>
							</li>
							<li id="jr_gcf" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_gcf.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.google.com/chromeframe/">Google Chrome Frame <i>(doesn't require admin)</i></a></div>
							</li>
							<li id="jr_msie" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_msie.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.microsoft.com/windows/Internet-explorer/">Internet Explorer <b style="color: #00f; background-color: #fff;"><?php echo $ieversion; ?></b></a></div>
							</li>
							<li id="jr_firefox" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_firefox.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.mozilla.com/firefox/new">Firefox <?php echo $chromeversion; ?></a></div>
							</li>
							<li id="jr_opera" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_opera.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.opera.com/download/">Opera <?php echo $operaversion; ?></a></div>
							</li>
							<li id="jr_safari" style="background-image: url(<?php echo plugins_url('/browsers/background_browser.gif', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; ">
								<div class="jr_icon" style="background-image: url(<?php echo plugins_url('/browsers/browser_safari.png', __FILE__); ?>); background-attachment: scroll; background-color: transparent; background-position: 0% 0%; background-repeat: no-repeat no-repeat; "></div>
								<div><a href="http://www.apple.com/safari/">Safari <?php echo $safariversion; ?></a></div>
							</li>
						</ul>
						<?php if (brejectr_options_getOption('closeoption')) { ?>
							<div id="jr_close">
								<a href="#"><?php echo brejectr_options_getOption('closelink'); ?></a>
								<p><?php echo brejectr_options_getOption('closemessage'); ?></p>
							</div>
						<?php } ?>
					</div>
				</td></tr>
			</table>
						
			<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			</p>
		</form>

	</div>
	<?php	
} //options page

// Sanitize and validate input. Accepts an array, return a sanitized array.
function brejectr_validate_options($input) {
	//nothing to validate at the moment with these options
	
	return $input;
}

function brejectr_validator_getoption($theoption, $thearray) {
	//if this check isn't made, wordpress gets confused and 
	//sends an error message for each key whose value is null
	//so when "checkbox" options are unchecked, for example,
	//an error is thrown instead of false being returned.
	if(array_key_exists( $theoption, $thearray ))
		return $thearray[$theoption];
	else
		return false;
}

// Display a Settings link on the main Plugins page
function brejectr_plugin_action_links( $links, $file ) {

	if ( $file == plugin_basename( __FILE__ ) ) {
		$brejectr_links = '<a href="'.get_admin_url().'options-general.php?page=browser-rejector%2Fbrowser-rejector.php">'.__('Settings').'</a>';
		// make the 'Settings' link appear first
		array_unshift( $links, $brejectr_links );
	}

	return $links;
}

//provides an easier way to safely get options
function brejectr_options_getOption($the_option) {
	$options = get_option('brejectr_options');
	//if this check isn't made, wordpress gets confused and 
	//sends an error message for each key whose value is null
	//so when "checkbox" options are unchecked, for example,
	//an error is thrown instead of false being returned.
	if(array_key_exists( $the_option, $options ))
		return $options[$the_option];
	else
		return false;
}
function brejectr_tftostring($inputtf) {
	if($inputtf)
		return 'true';
	else
		return 'false';
}
	
//tell wordpress to call the output 
add_action('wp_enqueue_scripts', 'brejectr_sss');

function brejectr_sss() {
	wp_enqueue_script('jreject', plugins_url('jquery.reject.js', __FILE__), array( 'jquery' ));
	$wppath = ABSPATH . '/wp-load.php';
	wp_enqueue_script('rejectr', plugins_url('rejectr.js.php?wppath=' . $wppath, __FILE__), array( 'jquery', 'jreject' ));
	//$br_inputarray = array( 'wp_load_location' =>  );
	//wp_localize_script( 'rejectr', 'wp_load_location_object', $br_inputarray );
	wp_enqueue_style('jreject', plugins_url('jquery.reject.css', __FILE__));
}
?>